package eu.dnetlib.bioschemas.api.publisher;

import eu.dnetlib.bioschemas.api.ServiceScrapeDriver;
import eu.dnetlib.common.controller.AbstractDnetController;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.LineIterator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.nio.charset.StandardCharsets;

/**
 * @author enrico.ottonello
 *
 */

@RestController
@RequestMapping("/api")
public class BioschemasAPIController extends AbstractDnetController {

	@Value("${outputFolder}")
	private String outputFolder;
	@Value("${outputDataPattern}")
	private String outputDataPattern;

	private static Logger logger = LoggerFactory.getLogger(BioschemasAPIController.class);

	@RequestMapping(value = "/startScraping", method = RequestMethod.GET)
	public String startScraping(@RequestParam final String datasourceKey, @RequestParam final String sitemapUrl) throws BioschemasException, IOException {

		logger.info("<STARTSCRAPING> datasourceKey: "+datasourceKey+" sitemapUrl:"+sitemapUrl);

		String sitemapUrlKey = "loc";
		String outputFilename = datasourceKey.concat(getOutputDataPattern());
		ServiceScrapeDriver service = new ServiceScrapeDriver(sitemapUrl, sitemapUrlKey, null, outputFilename);
		service.start();
		return "started";
	}

	@RequestMapping(value = "/getNQuads", method = RequestMethod.GET)
	public String getNQuads(@RequestParam final String datasourceKey, HttpServletResponse response) throws BioschemasException, IOException {

		logger.info("<GETNQUADS> datasourceKey: "+datasourceKey);

		LineIterator it = FileUtils.lineIterator(new File(getOutputFolder().concat("/").concat(datasourceKey).concat(getOutputDataPattern())), "UTF-8");
		try {
			while (it.hasNext()) {
				String line = it.nextLine();
				response.getOutputStream().write(line.getBytes(StandardCharsets.UTF_8));
				response.getOutputStream().println();
			}
		} finally {
		}
		return "";
	}

	public String getOutputFolder() {
		return outputFolder;
	}

	public String getOutputDataPattern() {
		return outputDataPattern;
	}
}